% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/lrt.R
\name{biv_lrt}
\alias{biv_lrt}
\title{Tests of homogeneity and independence in bivariate sine von
Mises and wrapped Cauchy distributions}
\usage{
biv_lrt(x, hom = FALSE, indep = FALSE, fit_mle = NULL, type, ...)
}
\arguments{
\item{x}{matrix of dimension  \code{c(n, 2)} containing the \code{n}
observations of the pair of angles.}

\item{hom}{test the homogeneity hypothesis? Defaults to \code{FALSE}.}

\item{indep}{test the independence hypothesis? Defaults to \code{FALSE}.}

\item{fit_mle}{output of \code{\link{fit_bvm_mle}} or
\code{\link{fit_bwc_mle}} with \code{hom = FALSE}. Computed internally if
not provided.}

\item{type}{either \code{"bvm"} (bivariate sine von Mises) or \code{"bwc"}
(bivariate wrapped Cauchy).}

\item{...}{optional parameters passed to \code{\link{fit_bvm_mle}} and
\code{\link{fit_bwc_mle}}, such as \code{start}, \code{lower}, or
\code{upper}.}
}
\value{
A list with class \code{htest}:
\item{statistic}{the value of the likelihood ratio test statistic.}
\item{p.value}{the \eqn{p}-value of the test (computed using the asymptotic
distribution).}
\item{alternative}{a character string describing the alternative
hypothesis.}
\item{method}{description of the type of test performed.}
\item{df}{degrees of freedom.}
\item{data.name}{a character string giving the name of \code{theta}.}
\item{fit_mle}{maximum likelihood fit.}
\item{fit_null}{maximum likelihood fit under the null hypothesis.}
}
\description{
Performs the following likelihood ratio tests for the
concentrations in bivariate sine von Mises and wrapped Cauchy distributions:
(1) \emph{homogeneity}: \eqn{H_0:\kappa_1=\kappa_2} vs.
\eqn{H_1:\kappa_1\neq\kappa_2}, and \eqn{H_0:\xi_1=\xi_2} vs.
\eqn{H_1:\xi_1\neq\xi_2}, respectively;
(2) \emph{independence}: \eqn{H_0:\lambda=0} vs.
\eqn{H_1:\lambda\neq0}, and \eqn{H_0:\rho=0} vs. \eqn{H_1:\rho\neq0}.
The tests (1) and (2) can be performed simultaneously.
}
\examples{
## Bivariate sine von Mises

# Homogeneity
n <- 200
mu <- c(0, 0)
kappa_0 <- c(1, 1, 0.5)
kappa_1 <- c(0.7, 0.1, 0.25)
samp_0 <- r_bvm(n = n, mu = mu, kappa = kappa_0)
samp_1 <- r_bvm(n = n, mu = mu, kappa = kappa_1)
biv_lrt(x = samp_0, hom = TRUE, type = "bvm")
biv_lrt(x = samp_1, hom = TRUE, type = "bvm")

# Independence
kappa_0 <- c(0, 1, 0)
kappa_1 <- c(1, 0, 1)
samp_0 <- r_bvm(n = n, mu = mu, kappa = kappa_0)
samp_1 <- r_bvm(n = n, mu = mu, kappa = kappa_1)
biv_lrt(x = samp_0, indep = TRUE, type = "bvm")
biv_lrt(x = samp_1, indep = TRUE, type = "bvm")

# Independence and homogeneity
kappa_0 <- c(3, 3, 0)
kappa_1 <- c(3, 1, 0)
samp_0 <- r_bvm(n = n, mu = mu, kappa = kappa_0)
samp_1 <- r_bvm(n = n, mu = mu, kappa = kappa_1)
biv_lrt(x = samp_0, indep = TRUE, hom = TRUE, type = "bvm")
biv_lrt(x = samp_1, indep = TRUE, hom = TRUE, type = "bvm")

## Bivariate wrapped Cauchy

# Homogeneity
xi_0 <- c(0.5, 0.5, 0.25)
xi_1 <- c(0.7, 0.1, 0.5)
samp_0 <- r_bwc(n = n, mu = mu, xi = xi_0)
samp_1 <- r_bwc(n = n, mu = mu, xi = xi_1)
biv_lrt(x = samp_0, hom = TRUE, type = "bwc")
biv_lrt(x = samp_1, hom = TRUE, type = "bwc")

# Independence
xi_0 <- c(0.1, 0.5, 0)
xi_1 <- c(0.3, 0.5, 0.2)
samp_0 <- r_bwc(n = n, mu = mu, xi = xi_0)
samp_1 <- r_bwc(n = n, mu = mu, xi = xi_1)
biv_lrt(x = samp_0, indep = TRUE, type = "bwc")
biv_lrt(x = samp_1, indep = TRUE, type = "bwc")

# Independence and homogeneity
xi_0 <- c(0.2, 0.2, 0)
xi_1 <- c(0.1, 0.2, 0.1)
samp_0 <- r_bwc(n = n, mu = mu, xi = xi_0)
samp_1 <- r_bwc(n = n, mu = mu, xi = xi_1)
biv_lrt(x = samp_0, indep = TRUE, hom = TRUE, type = "bwc")
biv_lrt(x = samp_1, indep = TRUE, hom = TRUE, type = "bwc")
}
\references{
Kato, S. and Pewsey, A. (2015). A Möbius transformation-induced distribution
on the torus. \emph{Biometrika}, 102(2):359--370. \doi{10.1093/biomet/asv003}

Singh, H., Hnizdo, V., and Demchuk, E. (2002). Probabilistic model for two
dependent circular variables. \emph{Biometrika}, 89(3):719--723.
\doi{10.1093/biomet/89.3.719}
}
